@@ -626,10 +626,15 @@ int FatController::controlIt(int pidfilefd) {
     }
 
     if (sig_term_killall) {
+        struct sigaction sa, oldsa;
+        memset(&sa, 0, sizeof(sa)); sa.sa_handler = SIG_IGN;
+        sigaction(SIGTERM, &sa, &oldsa); // ignore sigterm for us
         kill(0, SIGTERM);  // send everyone in this process group a TERM
-    }	                   // which causes them to exit as the default action
+                           // which causes them to exit as the default action
                            // but it also seems to send itself a TERM
-                           // which gets queued
+                           // so we ignore it
+        sigaction(SIGTERM, &oldsa, NULL); // restore prev state
+    }
 
 
     if (reloadconfig) {
