@@ -60,7 +60,7 @@ void HTTPHeader::checkheader() {  // this is used to fix bugs in certain
             header[i] = "Accept-Encoding:" + header[i].after("Accept-encoding:");
         }
         if (header[i].startsWith("Accept-Encoding:")) {
-            header[i] = modifyEncodings(header[i]);
+            header[i] = modifyEncodings(header[i]) + "\r";
         }
 
         if (header[i].startsWith("Connection: keep-alive")) {
@@ -70,11 +70,11 @@ void HTTPHeader::checkheader() {  // this is used to fix bugs in certain
             header[i] = "Connection: Keep-Alive" + header[i].after("Connection: Keep-alive");
         }
         if (header[i].startsWith("Proxy-Connection: Keep-Alive")) {
-            header[i] = "Proxy-Connection: Close";  // Need to force HTTP/1.1
+            header[i] = "Proxy-Connection: Close\r";  // Need to force HTTP/1.1
                     // clients and servers to use non persistant connections
         }
         if (header[i].startsWith("Connection: Keep-Alive")) {
-            header[i] = "Connection: Close";  // ditto
+            header[i] = "Connection: Close\r";  // ditto
         }
         if (header[i].startsWith("Proxy-authorization:")) {
             header[i] = "Proxy-Authorization:" + header[i].after("Proxy-authorization:");
@@ -248,7 +248,7 @@ String HTTPHeader::url() {
         if (answer[0] == '/') {  // must be the latter above
             for (i = 1; i < (signed)header.size(); i++) {
                 if (header[i].startsWith("Host:")) {
-                    hostname = header[i].after(" ");
+                    hostname = header[i].after(":");
                     hostname.removeMultiChar(' ');
                     if (hostname.contains(":")) {
                         hostname = hostname.before(":");  // chop off the port bit but it should never be there
@@ -526,17 +526,18 @@ String HTTPHeader::requesttype() {  // GET,HEAD,PUT,etc - what?
 void HTTPHeader::out(Socket *sock) throw(exception) {
     String l;  // for amalgamating to avoid conflict with the Nagel algorithm
     for(int i = 0; i < (signed)header.size(); i++) {
-        l = header[i] + "\n";
-        // need exception for bad write
-        if (!(*sock).writeToSocket(l.toCharArray(), l.length(), 0, timeout)) {
-            throw exception();
-        }
-    }  // send each line of the header to the output stream
+        l += header[i] + "\n";
+    }
+
+    l += "\r\n";
+
+    // send header to the output stream
     // need exception for bad write
-    if (!(*sock).writeToSocket("\r\n", 2, 0, timeout)) {
+
+    if (!(*sock).writeToSocket(l.toCharArray(), l.length(), 0, timeout)) {
         throw exception();
     }
-//    if ( ((String) (header[0])).before(" ") == "POST") {
+
     if (postdata.buffer_length > 0) {
         postdata.out(sock);
     }
